@@ -25,7 +25,7 @@ class App extends Component<{}> {
     return (
       <View style={styles.container}>
         <Text style={styles.welcome}>
-          This is Benoit app !
+          This is Benoit app Titi !
         </Text>
         <Text style={styles.instructions}>
           Wanna get stared ? Edit App.js
